const Email = require('@pubsweet/component-send-email')
const config = require('config')
const helpers = require('./helpers/helpers')

const confirmSignUp = config.get('confirm-signup.url')
const resetPath = config.get('invite-reset-password.url')
const resetPasswordPath = config.get('invite-reviewer.url')
const forgotPath = config.get('forgot-password.url')

module.exports = {
  sendSimpleEmail: async ({
    toEmail = '',
    user = {},
    emailType = '',
    dashboardUrl = '',
    meta = {},
  }) => {
    let subject, textBody
    let emailTemplate = 'simpleCTA'
    const replacements = {}
    switch (emailType) {
      case 'assign-handling-editor':
        subject = 'Hindawi Handling Editor Invitation'
        replacements.headline =
          'You have been assigned as a Handling Editor to a manuscript.'
        replacements.paragraph =
          'Please click on the link below to access your dashboard.'
        replacements.previewText = 'An Editor in Chief has assigned you'
        replacements.buttonText = 'VIEW DASHBOARD'
        replacements.url = dashboardUrl
        textBody = `${replacements.headline} ${replacements.paragraph} ${
          replacements.url
        } ${replacements.buttonText}`
        break
      case 'add-author':
        subject = 'Manuscript Assignment on Hindawi'
        replacements.headline =
          'You have been assigned as an Author to a manuscript.'
        replacements.paragraph =
          "The manuscript will become visible on your dashboard once it's submitted. Please click on the link below to access your dashboard."
        replacements.previewText = 'You are now an author'
        replacements.buttonText = 'VIEW DASHBOARD'
        replacements.url = dashboardUrl
        textBody = `${replacements.headline} ${replacements.paragraph} ${
          replacements.url
        } ${replacements.buttonText}`
        break
      case 'signup':
        subject = 'Confirm your email address'
        replacements.headline = ''
        replacements.paragraph =
          'Please confirm your account by clicking on the link below.'
        replacements.previewText = 'Hindawi account confirmation'
        replacements.buttonText = 'CONFIRM'
        replacements.url = helpers.createUrl(dashboardUrl, confirmSignUp, {
          userId: user.id,
          confirmationToken: meta.confirmationToken,
        })
        textBody = `${replacements.headline} ${replacements.paragraph} ${
          replacements.url
        } ${replacements.buttonText}`
        break
      case 'invite-author':
        subject = 'Author Invitation'
        replacements.headline =
          'You have been invited to join Hindawi as an Author.'
        replacements.paragraph =
          'Please confirm your account and set your account details by clicking on the link below.'
        replacements.previewText = 'You have been invited'
        replacements.buttonText = 'CONFIRM'
        replacements.url = helpers.createUrl(dashboardUrl, resetPath, {
          email: user.email,
          token: user.passwordResetToken,
          firstName: user.firstName,
          lastName: user.lastName,
          affiliation: user.affiliation,
          title: user.title,
        })
        textBody = `${replacements.headline} ${replacements.paragraph} ${
          replacements.url
        } ${replacements.buttonText}`
        break
      case 'invite':
        subject = 'Hindawi Invitation'
        replacements.headline = 'You have been invited to join Hindawi.'
        replacements.paragraph =
          'You can now join Hindawi. Please confirm your account and set your account details by clicking on the link below.'
        replacements.previewText = 'You have been invited'
        replacements.buttonText = 'CONFIRM'
        replacements.url = helpers.createUrl(dashboardUrl, resetPath, {
          email: user.email,
          token: user.passwordResetToken,
          firstName: user.firstName,
          lastName: user.lastName,
          affiliation: user.affiliation,
          title: user.title,
        })
        textBody = `${replacements.headline} ${replacements.paragraph} ${
          replacements.url
        } ${replacements.buttonText}`
        break
      case 'handling-editor-agreed':
        subject = 'Handling Editor Agreed'
        replacements.headline = `${user.firstName} ${
          user.lastName
        } agreed to be a Handling Editor on manuscript ${meta.collectionId}.`
        replacements.paragraph =
          'Please click on the link below to access your dashboard.'
        replacements.previewText = 'a user has is now handling editor'
        replacements.buttonText = 'VIEW DASHBOARD'
        replacements.url = dashboardUrl
        textBody = `${replacements.headline} ${replacements.paragraph} ${
          replacements.url
        } ${replacements.buttonText}`
        break
      case 'handling-editor-declined':
        subject = 'Handling Editor Declined'
        replacements.headline = `${user.firstName} ${
          user.lastName
        } has declined to be a Handling Editor on manuscript ${
          meta.collectionId
        }.`
        replacements.paragraph = meta.reason ? `Reason: "${meta.reason}"` : ''
        replacements.previewText = 'a user has declined your invitation'
        textBody = `${replacements.headline} ${replacements.paragraph}`
        emailTemplate = 'noCTA'
        break
      case 'revoke-handling-editor':
        subject = 'Invitation Has Been Cancelled'
        replacements.headline =
          'Your Handling Editor invitation to a manuscript has been revoked.'
        replacements.paragraph = ''
        replacements.previewText = 'you are no longer invited'
        textBody = `${replacements.headline}`
        emailTemplate = 'noCTA'
        break
      case 'manuscript-submitted':
        subject = `${meta.collection.customId}: Manuscript Submitted`
        replacements.previewText = 'A new manuscript has been submitted'
        replacements.headline = `A new manuscript has been submitted.`
        replacements.paragraph = `You can view the full manuscript titled "${
          meta.fragment.title
        }" by ${
          meta.fragment.authorName
        } and take further actions by clicking on the following link:`
        replacements.buttonText = 'MANUSCRIPT DETAILS'
        replacements.url = helpers.createUrl(
          dashboardUrl,
          `/projects/${meta.collection.id}/versions/${
            meta.fragment.id
          }/details`,
        )
        textBody = `${replacements.headline} ${replacements.paragraph} ${
          replacements.url
        } ${replacements.buttonText}`
        break
      case 'forgot-password':
        subject = 'Forgot Password'
        replacements.headline = 'You have requested a password reset.'
        replacements.paragraph =
          'In order to reset your password please click on the following link:'
        replacements.previewText = 'Click button to reset your password'
        replacements.buttonText = 'RESET PASSWORD'
        replacements.url = helpers.createUrl(dashboardUrl, forgotPath, {
          email: user.email,
          token: user.passwordResetToken,
        })
        textBody = `${replacements.headline} ${replacements.paragraph} ${
          replacements.url
        } ${replacements.buttonText}`
        break
      default:
        subject = 'Welcome to Hindawi!'
        break
    }

    const htmlBody = helpers.getEmailBody(emailTemplate, replacements)
    const mailData = {
      from: config.get('mailer.from'),
      to: toEmail,
      subject,
      text: textBody,
      html: htmlBody,
    }

    return Email.send(mailData)
  },
  sendReviewerInvitationEmail: async ({
    user,
    baseUrl,
    toEmail,
    subject,
    emailType,
    meta = {},
  }) => {
    let queryParams = {
      invitationId: meta.invitation.id,
      agree: true,
    }
    const manuscriptDetailsLink = `/projects/${meta.collection.id}/versions/${
      meta.fragment.id
    }/details`

    const declineUrl = helpers.createUrl(baseUrl, resetPasswordPath, {
      ...queryParams,
      agree: false,
      fragmentId: meta.fragment.id,
      collectionId: meta.collection.id,
      invitationToken: user.invitationToken,
    })

    let agreeUrl = helpers.createUrl(
      baseUrl,
      manuscriptDetailsLink,
      queryParams,
    )

    if (!user.isConfirmed) {
      queryParams = {
        ...queryParams,
        email: user.email,
        token: user.passwordResetToken,
        collectionId: meta.collection.id,
        fragmentId: meta.fragment.id,
        agree: true,
      }
      agreeUrl = helpers.createUrl(baseUrl, resetPasswordPath, queryParams)
    }
    const replacements = {
      agreeUrl,
      declineUrl,
      manuscriptDetailsUrl: helpers.createUrl(baseUrl, manuscriptDetailsLink),
      title: meta.fragment.title,
      authors: meta.fragment.authors,
      abstract: meta.fragment.abstract,
      previewText: 'invitation from Hindawi',
      intro: `Dear ${user.firstName} ${user.lastName}`,
      manuscriptText: '',
    }
    let textBody
    switch (emailType) {
      case 'invite-reviewer':
        replacements.upperContent = `A manuscript titled "${
          meta.fragment.title
        }" by ${meta.collection.authorName}, has been submitted
        for possible publication in Hindawi. As the Academic Editor handling the manuscript,
        I would be delighted if you would agree to review it and let me know whether you
        feel it is suitable for publication.`

        replacements.manuscriptText =
          "The manuscript's abstract, and author information is below to help you decide. Once you have agreed to review, you will be able to download the full article PDF."

        replacements.lowerContent = `If a potential conflict of interest exists between yourself and either the authors or
          the subject of the manuscript, please decline to handle the manuscript. If a conflict
          becomes apparent during the review process, please let me know at the earliest possible
          opportunity. For more information about our conflicts of interest policies, please
          see:
          <a href="https://www.hindawi.com/ethics/#coi">https://www.hindawi.com/ethics/#coi</a>.
          If you are able to review the manuscript, I would be grateful if you could submit your
          report by ${helpers.getExpectedDate(meta.invitation.timestamp, 14)}.`

        replacements.signatureName = meta.collection.handlingEditor.name
        replacements.signatureEmail = meta.collection.handlingEditor.email
        textBody = `${replacements.intro} ${replacements.upperContent} ${
          replacements.agreeUrl
        } ${replacements.declineUrl} ${replacements.manuscriptText} ${
          replacements.lowerContent
        } ${replacements.signature}`
        break
      case 'resend-reviewer':
        replacements.upperContent = `On ${helpers.getExpectedDate(
          meta.invitation.timestamp,
          0,
        )} I sent you a request to review the manuscript titled "${
          meta.fragment.title
        }" by ${
          meta.collection.authorName
        }, submitted for possible publication in Hindawi.
          I would be grateful if you would agree to review it and let me know whether you feel
          it is suitable for publication. If you are unable to review this manuscript then
          please decline to review. More details are available by clicking the link.`

        replacements.lowerContent =
          'I would like to thank you in advance for your help with the evaluation of this manuscript, since it would not be possible for us to run the journal without the help of our reviewers. I am looking forward to hearing from you.'

        replacements.signatureName = meta.collection.handlingEditor.name
        replacements.signatureEmail = meta.collection.handlingEditor.email
        textBody = `${replacements.intro} ${replacements.upperContent} ${
          replacements.agreeUrl
        } ${replacements.declineUrl} ${replacements.lowerContent} ${
          replacements.signatureName
        } ${replacements.signatureEmail}`
        break
      default:
        break
    }

    const htmlBody = helpers.getInvitationBody('invitation', replacements)
    const mailData = {
      from: config.get('mailer.from'),
      to: toEmail,
      subject,
      text: textBody,
      html: htmlBody,
    }
    return Email.send(mailData)
  },
  sendNotificationEmail: async ({
    toEmail,
    user,
    emailType,
    meta = { privateNote: '' },
  }) => {
    let subject, textBody

    const emailTemplate = 'notification'
    const detailsUrl = meta.baseUrl
      ? helpers.createUrl(
          meta.baseUrl,
          `/projects/${meta.collection.id}/versions/${
            meta.fragment.id
          }/details`,
        )
      : ''
    const replacements = {
      detailsUrl,
      beforeAnchor: '',
      afterAnchor: '',
      hasLink: true,
    }
    switch (emailType) {
      case 'unassign-reviewer':
        subject = `${meta.collection.customId}: Review Unassigned`
        replacements.previewText = 'notification from Hindawi'
        replacements.intro = `Dear ${user.firstName} ${user.lastName}`

        replacements.paragraph = `You are no longer needed to review the article titled "${
          meta.fragment.title
        }" by ${
          meta.fragment.authorName
        }. If you have comments on this manuscript you believe the Editor should
          see, please email them to ${config.get(
            'mailer.from',
          )} as soon as possible. Thank you for your
          time and I hope you will consider reviewing for Hindawi again.`
        replacements.beforeAnchor = 'Please visit the'
        replacements.afterAnchor = 'to see the full review'
        replacements.signatureName = meta.handlingEditorName
        textBody = `${replacements.intro} ${replacements.paragraph} ${
          replacements.beforeAnchor
        } ${replacements.detailsUrl} ${replacements.afterAnchor} ${
          replacements.signatureName
        }`
        break
      case 'review-submitted':
        subject = `${meta.collection.customId}: Manuscript Review`
        replacements.previewText = 'a new review has been submitted'
        replacements.intro = `Dear ${meta.handlingEditorName}`

        replacements.paragraph = `We are pleased to inform you that Dr. ${
          meta.reviewerName
        } has submitted a review for the manuscript titled "${
          meta.fragment.title
        }" by ${meta.fragment.authorName}.`
        replacements.beforeAnchor = 'Please visit the'
        replacements.afterAnchor = 'to see the full review'

        replacements.signatureName = meta.eicName
        textBody = `${replacements.intro} ${replacements.paragraph} ${
          replacements.beforeAnchor
        } ${replacements.detailsUrl} ${replacements.afterAnchor} ${
          replacements.signatureName
        }`
        break
      case 'reviewer-agreed':
        subject = `${meta.collection.customId}: Manuscript Reviews`
        replacements.previewText = 'a user has agreed to review'
        replacements.intro = `Dear ${meta.handlingEditorName}`

        replacements.paragraph = `We are pleased to inform you that Dr. ${
          user.firstName
        } ${user.lastName} has agreed to review the manuscript titled "${
          meta.fragment.title
        }" by ${
          meta.fragment.authorName
        }. You should receive the report by Dr. ${user.firstName} ${
          user.lastName
        } before ${helpers.getExpectedDate(meta.timestamp, 14)}.`
        replacements.beforeAnchor =
          'If you have any queries, or would like to send a reminder if you no report has been submitted, then please visit the'
        replacements.afterAnchor = 'to see the full review'

        replacements.signatureName = meta.eicName
        textBody = `${replacements.intro} ${replacements.paragraph} ${
          replacements.beforeAnchor
        } ${replacements.detailsUrl} ${replacements.afterAnchor} ${
          replacements.signatureName
        }`
        break
      case 'reviewer-declined':
        subject = `${meta.collection.customId}: Manuscript Reviews`
        replacements.previewText = 'a user has declined to review'
        replacements.intro = `Dear ${meta.handlingEditorName}`
        replacements.paragraph = `We regret to inform you that Dr. ${
          user.firstName
        } ${user.lastName} has declined to review the manuscript titled "${
          meta.fragment.title
        }" by ${meta.fragment.authorName}.`
        replacements.beforeAnchor = 'Please visit the'
        replacements.afterAnchor =
          'to see if you need to invite any additional reviewers in order to reach a decision on the manuscript'
        replacements.signatureName = meta.eicName
        textBody = `${replacements.intro} ${replacements.paragraph} ${
          replacements.beforeAnchor
        } ${replacements.detailsUrl} ${replacements.afterAnchor} ${
          replacements.signatureName
        }`
        break
      case 'reviewer-thank-you':
        subject = `${meta.collection.customId}: Manuscript Review`
        replacements.previewText = 'Hindawi says thank you'
        replacements.intro = `Dear Dr. ${user.firstName} ${user.lastName}`

        replacements.paragraph = `Thank you for agreeing to review the manuscript titled "${
          meta.fragment.title
        }" by ${meta.fragment.authorName}.`
        replacements.beforeAnchor =
          'You can view the full PDF file of the manuscript and post your review report using the following URL:'
        replacements.signatureName = meta.handlingEditorName
        textBody = `${replacements.intro} ${replacements.paragraph} ${
          replacements.beforeAnchor
        } ${replacements.detailsUrl} ${replacements.afterAnchor} ${
          replacements.signatureName
        }`
        break
      case 'agreed-reviewers-after-recommendation':
        subject = meta.emailSubject
        replacements.hasLink = false
        replacements.previewText =
          'a manuscript has received a recommendation based on reviews'
        replacements.intro = `Dear Dr. ${meta.reviewerName}`

        replacements.paragraph = `I appreciate any time you may have spent reviewing manuscript "${
          meta.fragment.title
        }" by ${
          meta.fragment.authorName
        }. However, an editorial decision has been made and the review of this manuscript is now complete. I apologize for any inconvenience. <br/>
        If you have comments on this manuscript you believe the Editor should see, please email them to Hindawi as soon as possible. <br/>
        Thank you for your interest and I hope you will consider reviewing for Hindawi again.`
        delete replacements.detailsUrl
        replacements.signatureName = meta.editorName
        textBody = `${replacements.intro} ${replacements.paragraph} ${
          replacements.signatureName
        }`
        break
      case 'no-response-reviewers-after-recommendation':
        subject = meta.emailSubject
        replacements.hasLink = false
        replacements.previewText = 'a manuscript has reached a decision'
        replacements.intro = `Dear Dr. ${meta.reviewerName}`

        replacements.paragraph = `An editorial decision has been made regarding the ${
          meta.manuscriptType
        } titled "${meta.fragment.title}" by ${
          meta.fragment.authorName
        }. So, you do not need to proceed with the review of this manuscript. <br/><br/>
        If you have comments on this manuscript you believe the Editor should see, please email them to Hindawi as soon as possible.`
        delete replacements.detailsUrl
        replacements.signatureName = meta.editorName
        textBody = `${replacements.intro} ${replacements.paragraph} ${
          replacements.signatureName
        }`
        break
      case 'eic-recommendation':
        subject = `${meta.collection.customId}: Manuscript Recommendation`
        replacements.previewText =
          'a handling editor has submitted a recommendation'
        replacements.intro = `Dear Dr. ${meta.eicName}`
        replacements.paragraph = meta.paragraph
        replacements.beforeAnchor =
          'For more information about what is required, please visit the '
        replacements.signatureName = meta.handlingEditorName
        textBody = `${replacements.intro} ${replacements.paragraph} ${
          replacements.beforeAnchor
        } ${replacements.detailsUrl} ${replacements.afterAnchor} ${
          replacements.signatureName
        }`
        break
      case 'author-request-to-revision':
        subject = `${meta.collection.customId}: Manuscript Recommendation`
        replacements.previewText =
          'a handling editor has submitted a recommendation'
        replacements.intro = `Dear Dr. ${meta.fragment.authorName}`
        replacements.paragraph = `In order for the manuscript titled "${
          meta.fragment.title
        }" by ${
          meta.fragment.authorName
        } to proceed to publication, there needs to be a revision. <br/><br/>
        ${meta.authorNoteText}<br/><br/>`
        replacements.beforeAnchor =
          'For more information about what is required, please visit the '
        replacements.signatureName = meta.handlingEditorName
        textBody = `${replacements.intro} ${replacements.paragraph} ${
          replacements.beforeAnchor
        } ${replacements.detailsUrl} ${replacements.signatureName}`
        break
      case 'author-manuscript-rejected':
        subject = `${meta.collection.customId}: Manuscript Rejected`
        replacements.previewText = 'a manuscript has been rejected'
        replacements.intro = `Dear Dr. ${meta.fragment.authorName}`
        replacements.paragraph = `I am sorry to inform you that manuscript titled "${
          meta.fragment.title
        }" by ${
          meta.fragment.submittingAuthorName
        } has been rejected for publication. <br/><br/>
        ${meta.authorNoteText}<br/><br/>`
        replacements.hasLink = false
        delete replacements.detailsUrl
        replacements.signatureName = meta.handlingEditorName
        textBody = `${replacements.intro} ${replacements.paragraph} ${
          replacements.signatureName
        }`
        break
      case 'author-manuscript-published':
        subject = `${meta.collection.customId}: Manuscript Decision`
        replacements.previewText = 'a manuscript has been published'
        replacements.intro = `Dear Dr. ${meta.fragment.authorName}`
        replacements.paragraph = `I am delighted  to inform you that manuscript titled "${
          meta.fragment.title
        }" by ${
          meta.fragment.submittingAuthorName
        } has passed through the review process and will be published in Hindawi.<br/><br/>
        ${meta.authorNoteText}<br/><br/>
        Thanks again for choosing to publish with us.`
        replacements.hasLink = false
        delete replacements.detailsUrl
        replacements.signatureName = meta.handlingEditorName
        textBody = `${replacements.intro} ${replacements.paragraph} ${
          replacements.signatureName
        }`
        break
      case 'he-manuscript-rejected':
        subject = meta.emailSubject
        replacements.hasLink = false
        replacements.previewText = 'a manuscript has been rejected'
        replacements.intro = `Dear Dr. ${meta.handlingEditorName}`

        replacements.paragraph = `Thank you for your recommendation to reject the manuscript titled "${
          meta.fragment.title
        }" by ${
          meta.fragment.authorName
        } based on the reviews you received.<br/><br/>
        I can confirm this article has now been rejected.`
        delete replacements.detailsUrl
        replacements.signatureName = meta.eicName
        textBody = `${replacements.intro} ${replacements.paragraph} ${
          replacements.signatureName
        }`
        break
      case 'he-manuscript-published':
        subject = meta.emailSubject
        replacements.hasLink = false
        replacements.previewText = 'a manuscript has been published'
        replacements.intro = `Dear Dr. ${meta.handlingEditorName}`

        replacements.paragraph = `Thank you for your recommendation to publish the manuscript titled "${
          meta.fragment.title
        }" by ${
          meta.fragment.authorName
        } based on the reviews you received.<br/><br/>
        I can confirm this article will now go through to publication.`
        delete replacements.detailsUrl
        replacements.signatureName = meta.eicName
        textBody = `${replacements.intro} ${replacements.paragraph} ${
          replacements.signatureName
        }`
        break
      case 'he-manuscript-return-with-comments':
        subject = meta.emailSubject
        replacements.hasLink = false
        replacements.previewText =
          'a manuscript has been returned with comments'
        replacements.intro = `Dear Dr. ${meta.handlingEditorName}`

        replacements.paragraph = `Thank you for your recommendation for the manuscript titled "${
          meta.fragment.title
        }" by ${
          meta.fragment.authorName
        } based on the reviews you received.<br/><br/>
        ${meta.eicComments}<br/><br/>`
        delete replacements.detailsUrl
        replacements.signatureName = meta.eicName
        textBody = `${replacements.intro} ${replacements.paragraph} ${
          replacements.signatureName
        }`
        break
      case 'submitting-reviewers-after-decision':
        subject = meta.emailSubject
        replacements.hasLink = false
        replacements.previewText = 'a decision has been made on a manuscript'
        replacements.intro = `Dear Dr. ${meta.reviewerName}`

        replacements.paragraph = `Thank you for your review on the manuscript titled "${
          meta.fragment.title
        }" by ${
          meta.fragment.authorName
        }. After taking into account the reviews and the recommendation of the Handling Editor, I can confirm this article ${
          meta.emailText
        }.<br/><br/>
        If you have any queries about this decision, then please email them to Hindawi as soon as possible.`
        delete replacements.detailsUrl
        replacements.signatureName = meta.editorName
        textBody = `${replacements.intro} ${replacements.paragraph} ${
          replacements.signatureName
        }`
        break
      case 'new-version-submitted':
        subject = `${meta.collection.customId}: Manuscript Update`
        replacements.previewText = 'A manuscript has been updated'
        replacements.intro = `Dear Dr. ${meta.handlingEditorName}`

        replacements.paragraph = `A new version of the manuscript titled "${
          meta.fragment.title
        }" by ${meta.fragment.authorName} has been submitted.`
        replacements.beforeAnchor =
          'Previous reviewers have been automatically invited to review the manuscript again. Please visit the'
        replacements.afterAnchor =
          'to see the latest version and any other actions you may need to take'

        replacements.signatureName = meta.eicName
        textBody = `${replacements.intro} ${replacements.paragraph} ${
          replacements.beforeAnchor
        } ${replacements.detailsUrl} ${replacements.afterAnchor} ${
          replacements.signatureName
        }`
        break
      case 'submitting-reviewers-after-revision':
        subject = meta.emailSubject
        replacements.previewText = 'A manuscript has been updated'
        replacements.intro = `Dear Dr. ${meta.reviewerName}`

        replacements.paragraph = `A new version of the manuscript titled "${
          meta.fragment.title
        }" by ${meta.fragment.authorName} has been submitted.`
        replacements.beforeAnchor = `As you have reviewed the previous version of this manuscript, I would be grateful if you can review this revised version and submit a review report by ${helpers.getExpectedDate(
          meta.timestamp,
          14,
        )}. You can download the PDF of the revised version and submit your new review from the following URL:`

        replacements.signatureName = meta.editorName
        textBody = `${replacements.intro} ${replacements.paragraph} ${
          replacements.beforeAnchor
        } ${replacements.detailsUrl} ${replacements.signatureName}`
        break
      default:
        subject = 'Hindawi Notification!'
        break
    }
    const htmlBody = helpers.getNotificationBody(emailTemplate, replacements)
    const mailData = {
      from: config.get('mailer.from'),
      to: toEmail,
      subject,
      text: textBody,
      html: htmlBody,
    }
    return Email.send(mailData)
  },
}
