const {
  Team,
  User,
  Email,
  services,
  Fragment,
  Collection,
  authsome: authsomeHelper,
} = require('pubsweet-component-helper-service')
const union = require('lodash/union')

module.exports = models => async (req, res) => {
  const { collectionId, fragmentId } = req.params
  let collection, fragment

  try {
    collection = await models.Collection.find(collectionId)
    if (!collection.fragments.includes(fragmentId))
      return res.status(400).json({
        error: `Collection and fragment do not match.`,
      })
    const fragLength = collection.fragments.length
    if (fragLength < 2) {
      return res.status(400).json({
        error: 'No previous version has been found.',
      })
    }
    fragment = await models.Fragment.find(fragmentId)

    const authsome = authsomeHelper.getAuthsome(models)
    const target = {
      fragment,
      path: req.route.path,
    }
    const canPatch = await authsome.can(req.user, 'PATCH', target)
    if (!canPatch)
      return res.status(403).json({
        error: 'Unauthorized.',
      })

    const collectionHelper = new Collection({ collection })
    const fragmentHelper = new Fragment({ fragment })
    const teamHelper = new Team({
      TeamModel: models.Team,
      collectionId,
      fragmentId,
    })
    const userHelper = new User({ UserModel: models.User })

    const reviewerIds = fragment.invitations.map(inv => {
      const { userId } = inv
      return userId
    })

    const reviewersTeam = await teamHelper.createTeam({
      role: 'reviewer',
      members: reviewerIds,
      objectType: 'fragment',
    })

    reviewerIds.forEach(id =>
      userHelper.updateUserTeams({
        userId: id,
        teamId: reviewersTeam.id,
      }),
    )

    const authorIds = fragment.authors.map(auth => {
      const { id } = auth
      return id
    })

    let authorsTeam = await teamHelper.getTeam({
      role: 'author',
      objectType: 'fragment',
    })

    if (!authorsTeam) {
      authorsTeam = await teamHelper.createTeam({
        role: 'author',
        members: authorIds,
        objectType: 'fragment',
      })
    } else {
      authorsTeam.members = union(authorsTeam.members, authorIds)
      await authorsTeam.save()
    }

    authorIds.forEach(id =>
      userHelper.updateUserTeams({
        userId: id,
        teamId: reviewersTeam.id,
      }),
    )

    const previousFragment = await models.Fragment.find(
      collection.fragments[fragLength - 2],
    )
    fragmentHelper.fragment = previousFragment

    const heRecommendation = fragmentHelper.getHeRequestToRevision()
    if (!heRecommendation) {
      return res.status(400).json({
        error: 'No Handling Editor request to revision has been found.',
      })
    }

    collectionHelper.updateStatusByRecommendation({
      recommendation: heRecommendation.recommendation,
    })

    fragment.submitted = Date.now()
    fragment = await fragment.save()

    const parsedFragment = await fragmentHelper.getFragmentData({
      handlingEditor: collection.handlingEditor,
    })
    const authors = await fragmentHelper.getAuthorData({
      UserModel: models.User,
    })
    const email = new Email({
      authors,
      collection,
      parsedFragment: { ...parsedFragment, id: fragment.id },
      UserModel: models.User,
      baseUrl: services.getBaseUrl(req),
    })
    email.setupNewVersionSubmittedEmail()

    if (heRecommendation.recommendation === 'major') {
      email.setupReviewersEmail({
        agree: true,
        isRevision: true,
        isSubmitted: true,
        FragmentModel: models.Fragment,
        newFragmentId: fragment.id,
      })
    }

    return res.status(200).json(fragment)
  } catch (e) {
    const notFoundError = await services.handleNotFoundError(e, 'Item')
    return res.status(notFoundError.status).json({
      error: notFoundError.message,
    })
  }
}
