import React from 'react'
import { get, omit, debounce } from 'lodash'
import PropTypes from 'prop-types'
import { connect } from 'react-redux'
import { th } from '@pubsweet/ui-toolkit'
import { actions } from 'pubsweet-client'
import { DragDropContext } from 'react-dnd'
import {
  Field,
  reduxForm,
  getFormValues,
  change as changeForm,
} from 'redux-form'
import styled, { css } from 'styled-components'
import HTML5Backend from 'react-dnd-html5-backend'
import { ValidatedField, Button } from '@pubsweet/ui'
import { AbstractEditor, TitleEditor } from 'xpub-edit'
import { AuthorList, Files } from 'pubsweet-components-faraday/src/components'
import AutosaveIndicator from 'pubsweet-component-wizard/src/components/AutosaveIndicator'
import {
  toClass,
  compose,
  withProps,
  withContext,
  withHandlers,
} from 'recompose'
import {
  FileItem,
  FilePicker,
} from 'pubsweet-components-faraday/src/components/Files'
import {
  uploadFile,
  deleteFile,
  getSignedUrl,
  getRequestStatus,
} from 'pubsweet-components-faraday/src/redux/files'

import { Expandable } from '../molecules/'

const TextAreaField = input => <Textarea {...input} height={70} rows={6} />
const SubmitRevision = ({
  addFile,
  project,
  version,
  removeFile,
  handleSubmit,
  responseFiles,
}) => (
  <Root>
    <Expandable label="Submit Revision" startExpanded>
      <Expandable label="DETAILS & AUTHORS">
        <Title>MANUSCRIPT TITLE*</Title>
        <ValidatedField
          component={input => <TitleEditor {...input} />}
          name="metadata.title"
        />
        <Title>ABSTRACT*</Title>
        <ValidatedField
          component={input => <AbstractEditor {...input} />}
          name="metadata.abstract"
        />
        <Title>AUTHORS DETAILS*</Title>
        <Field
          component={() => (
            <AuthorList authorPath="revision.authors" parentForm="revision" />
          )}
          name="authors"
        />
      </Expandable>
      <Expandable label="FILES">
        <Field
          component={() => (
            <Files filePath="revision.files" parentForm="revision" />
          )}
          name="files"
        />
      </Expandable>
      <Expandable label="RESPONSE TO REVIEWER COMMENTS" startExpanded>
        <Title>Reply text*</Title>
        <Row>
          <FullWidth className="full-width">
            <ValidatedField component={TextAreaField} name="response" />
          </FullWidth>
        </Row>
        <Row left>
          {responseFiles.map(file => (
            <FileItem
              compact
              id={file.id}
              key={file.id}
              {...file}
              removeFile={removeFile}
            />
          ))}
        </Row>
        <FilePicker
          allowedFileExtensions={['pdf', 'doc', 'docx', 'png']}
          onUpload={addFile}
        >
          <ActionText left={12}>Upload file</ActionText>
        </FilePicker>
      </Expandable>
      <SubmitContainer>
        <AutosaveIndicator formName="revision" />
        <Button onClick={handleSubmit} primary>
          SUBMIT REVISION
        </Button>
      </SubmitContainer>
    </Expandable>
  </Root>
)

const onChange = (values, dispatch, { project, version }) => {
  const newValues = omit(values, 'authorForm')
  dispatch(
    actions.updateFragment(project, {
      ...version,
      revision: newValues,
    }),
  )
}

export default compose(
  withContext(
    {
      version: PropTypes.object,
      project: PropTypes.object,
    },
    ({ project, version }) => ({
      project,
      version,
    }),
  ),
  connect(
    state => ({
      fileFetching: getRequestStatus(state),
      formValues: getFormValues('revision')(state),
    }),
    {
      changeForm,
      uploadFile,
      deleteFile,
      getSignedUrl,
      getRequestStatus,
    },
  ),
  withHandlers({
    addFile: ({ formValues = {}, uploadFile, changeForm, version }) => file => {
      uploadFile(file, 'responseToReviewers', version.id)
        .then(file => {
          const { files } = formValues
          const newFiles = files.responseToReviewers
            ? [...files.responseToReviewers, file]
            : [file]
          changeForm('revision', 'files', {
            ...files,
            responseToReviewers: newFiles,
          })
        })
        .catch(e => console.error(`Couldn't upload file.`, e))
    },
    removeFile: ({
      formValues: { files },
      changeForm,
      deleteFile,
    }) => id => e => {
      deleteFile(id)
        .then(r => {
          const newFiles = files.responseToReviewers.filter(f => f.id !== id)
          changeForm('revision', 'files', {
            ...files,
            responseToReviewers: newFiles,
          })
        })
        .catch(e => console.error(`Couldn't delete the file.`, e))
    },
  }),
  withProps(({ version, formValues }) => ({
    initialValues: {
      metadata: {
        title: get(version, 'revision.metadata.title') || '',
        abstract: get(version, 'revision.metadata.abstract') || '',
      },
      authors: get(version, 'revision.authors'),
      files: get(version, 'revision.files') || [],
      response: get(version, 'revision.response'),
    },
    responseFiles: get(formValues, 'files.responseToReviewers') || [],
  })),
  reduxForm({
    form: 'revision',
    onChange: debounce(onChange, 1000, { maxWait: 5000 }),
    onSubmit: () => {},
  }),
  DragDropContext(HTML5Backend),
  toClass,
)(SubmitRevision)

// #region styled-components
const defaultText = css`
  color: ${th('colorPrimary')};
  font-family: ${th('fontReading')};
  font-size: ${th('fontSizeBaseSmall')};
`

const Textarea = styled.textarea`
  border-color: ${({ hasError }) =>
    hasError ? th('colorError') : th('colorPrimary')};
  font-size: ${th('fontSizeBaseSmall')};
  font-family: ${th('fontWriting')};
  padding: calc(${th('subGridUnit')} * 2);
  transition: all 300ms linear;
  width: 100%;

  &:read-only {
    background-color: ${th('colorBackgroundHue')};
  }
`

const FullWidth = styled.div`
  flex: 1;
  > div {
    flex: 1;
  }
`

const Row = styled.div`
  ${defaultText};
  align-items: center;
  box-sizing: border-box;
  display: flex;
  flex-direction: row;
  flex: 1;
  flex-wrap: wrap;
  justify-content: ${({ left }) => (left ? 'left' : 'space-between')};

  div[role='alert'] {
    margin-top: 0;
  }
`

const ActionText = styled.span`
  ${defaultText};
  cursor: pointer;
  margin-left: ${({ left }) => left || 0}px;
  text-decoration: underline;
`

const Root = styled.div`
  background-color: ${th('colorBackground')};
`

const Title = styled.span`
  align-self: center;
  font-size: ${th('fontSizeBase')};
  margin-bottom: 10px;
`

const SubmitContainer = styled.div`
  align-items: center;
  display: flex;
  flex-direction: row;
  justify-content: flex-end;
  margin-top: calc(${th('subGridUnit')} * 2);
`
// #endregion
